==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.hkp/src/com/openexchange/guard/hkp/utils/CheckWhitelist.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.hkp.utils;

import org.apache.commons.net.util.SubnetUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.guard.common.java.Strings;
import com.openexchange.guard.configuration.GuardConfigurationService;
import com.openexchange.guard.configuration.GuardProperty;
import com.openexchange.guard.hkp.osgi.Services;

/**
 * {@link CheckWhitelist}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v2.4.0
 */
public class CheckWhitelist {

    private static final Logger LOG = LoggerFactory.getLogger(CheckWhitelist.class);

    /**
     * Check if the ip address is within the range of whitelist configured
     *
     * @param ip
     * @return
     */
    public static boolean isWhiteListed(String ip) {
        String whitlist = Services.getService(GuardConfigurationService.class).getProperty(GuardProperty.publicKeyWhitelist);
        if(whitlist == null || whitlist.isEmpty() ) {
            return false;
        }
        String[] splitByComma = Strings.splitByComma(whitlist);
        try {
            for (int i = 0; i < splitByComma.length; i++) {
                String whiteListIp = splitByComma[i];
                if(!whiteListIp.contains("/")){
                    //Single IP
                    if(whiteListIp.trim().equals(ip)){
                        return true;
                    }
                }
                else if(whiteListIp.contains("/")){
                    //CDIR notation
                    //TODO: support ipv6
                    SubnetUtils util = new SubnetUtils(splitByComma[i]);
                    if (util.getInfo().isInRange(ip)) {
                        return true;
                    }
                    if (util.getInfo().getAddress().equals(ip)) {
                        return true;
                    }
                }
            }
            return false;
        } catch (Exception e) {
            LOG.error("Problem checking pgp whitelist", e);
            return false;
        }
    }
}

==> open-xchange-guard_2.10.1.orig.tar.bz2: open-xchange-guard-2.10.1/com.openexchange.guard.hkp/src/com/openexchange/guard/hkp/utils/CheckWhitelist.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.hkp.utils;

import org.apache.commons.net.util.SubnetUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.exception.OXException;
import com.openexchange.guard.common.java.Strings;
import com.openexchange.guard.configuration.GuardConfigurationService;
import com.openexchange.guard.configuration.GuardProperty;
import com.openexchange.guard.hkp.osgi.Services;

/**
 * {@link CheckWhitelist}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v2.4.0
 */
public class CheckWhitelist {

    private static final Logger LOG = LoggerFactory.getLogger(CheckWhitelist.class);

    /**
     * Check if the ip address is within the range of whitelist configured
     *
     * @param ip
     * @return
     * @throws OXException
     */
    public static boolean isWhiteListed(String ip) throws OXException {
        String whitlist = Services.getService(GuardConfigurationService.class).getProperty(GuardProperty.publicKeyWhitelist);
        if(whitlist == null || whitlist.isEmpty() ) {
            return false;
        }
        String[] splitByComma = Strings.splitByComma(whitlist);
        try {
            for (int i = 0; i < splitByComma.length; i++) {
                String whiteListIp = splitByComma[i];
                if(!whiteListIp.contains("/")){
                    //Single IP
                    if(whiteListIp.trim().equals(ip)){
                        return true;
                    }
                }
                else if(whiteListIp.contains("/")){
                    //CDIR notation
                    //TODO: support ipv6
                    SubnetUtils util = new SubnetUtils(splitByComma[i]);
                    if (util.getInfo().isInRange(ip)) {
                        return true;
                    }
                    if (util.getInfo().getAddress().equals(ip)) {
                        return true;
                    }
                }
            }
            return false;
        } catch (Exception e) {
            LOG.error("Problem checking pgp whitelist", e);
            return false;
        }
    }
}
